""" demonstrates the use of MasterSelectWidget """

from Products.Archetypes.public import *
from AccessControl import ClassSecurityInfo
from Products.MasterSelectWidget.MasterSelectWidget import MasterSelectWidget

# define slave parameters for master1
slave_fields = ({'name': 'slaveField1',
                 'action': 'vocabulary',
                 'vocab_method': 'getSlaveVocab',
                 'control_param': 'master',
                 },# controls the vocab of slaveField1
                 {'name': 'slaveField1',
                 'action': 'hide',
                 'hide_values': ('6',),
                 },# controls the visibility of slaveField1 also
                 {'name': 'slaveField2',
                 'action': 'hide',
                 'hide_values': ('2','4'),
                 },# controls the visibility of slaveField2
                 {'name': 'slaveField3',
                 'action': 'disable',
                 'hide_values': ('1','5'),
                 },)# disables slaveField3

# define slave parameters for master2
slave_fields2 = ({'name': 'slaveMasterField',
                 'action': 'vocabulary',
                 'vocab_method': 'getSlaveVocab2',
                 'control_param': 'master',
                 },)# controls the vocab of slaveMasterField

# define slave parameters for slave_master
slave_master_fields = ({'name': 'slaveField4',
                       'action': 'hide',
                       'hide_values': ('c','g'),
                       },)# controls the visibility of slaveField4

schema = BaseSchema +  Schema((
    IntegerField('masterField',
                searchable=1,
                default='',
                vocabulary=['1','2','3','4','5','6'],
                widget=MasterSelectWidget(slave_fields = slave_fields,
                                          description="This field controls the vocabulary of slaveField1, the available values in slaveField1 will be equal to the numbers between the selected number and 10.  When the value 2 or 4 is selected, slaveField2 will be hidden.  When the value 1 or 5 is selected, slaveField3 will be disabled.  When value 6 is selected, slaveField one will be hidden.")
                ),
    LinesField('slaveField1',
                searchable=1,
                default='',
                vocabulary=['1','2','3','4','5','6'],
                widget=MultiSelectionWidget(format='select',
                                       description="This field's vocabulary is controlled by the value selected in masterField.  The values available here will be the numbers between the number selected in masterField and 10.  The field will be hidden when 6 is selected in the masterField."),
                ),
    IntegerField('slaveField2',
                searchable=1,
                default='',
                vocabulary=['10','20','30','40','50'],
                widget=SelectionWidget(format='select',
                                       description="This field's visiblity is controlled by the value selected in masterField.  It will become invisible when the values 2 or 4 are selected."),
                ),
    BooleanField('slaveField3',
                searchable=1,
                default='',
                vocabulary=['x','xx','xxx','il','l'],
                widget=BooleanWidget(format='select',
                                       description="This field's availability is controlled by the value selected in masterField.  It will be deactivated when the values 1 or 5 are selected."),
                ),
    StringField('masterField2',
                searchable=1,
                default='',
                vocabulary=['a','b','c','d','e','f'],
                widget=MasterSelectWidget(slave_fields = slave_fields2,
                                          description="This field controls the vocabulary of slaveMasterField, the available values in slaveMasterField will be the 5 letters after the selected letter."),
                ),
    StringField('slaveMasterField',
                searchable=1,
                default='',
                vocabulary=['1','2','3','4','5','6'],
                widget=MasterSelectWidget(slave_fields = slave_master_fields,
                                          description="This field's vocabulary is controlled by the value selected in masterField2.  The values available here will be the 5 letters after the selected letter.  This field also controls the visibility of slaveField4.  If the values c or g are selected slaveField4 will be hidden."),
                ),
    ReferenceField('slaveField4',
                searchable=1,
                default='',
                vocabulary=['z','y','x','w'],
                relationship="bad_news",
                widget=ReferenceWidget(description="This field's visiblity is controlled by the value selected in slaveMasterField.  It will become invisible when the values c or g are selected."),
                ),
))

class MasterSelectDemo(BaseContent):
    """
    Demo from MasterSelectWidget
    """
    content_icon = "document_icon.gif"
    schema = schema
    security = ClassSecurityInfo()
    global_allow = 0

    security.declarePublic('getSlaveVocab')
    def getSlaveVocab(self, master):
        """Vocab method that returns a vocabulary consisting of the numbers
           between the input number and 10
           (the displayed value has "num: " prepended)."""
        results = range(int(master)+1,10)
        results = [(str(a),"num: "+str(a)) for a in results]
        return DisplayList(results)

    security.declarePublic('getSlaveVocab2')
    def getSlaveVocab2(self, master):
        """Vocab method that returns a vocabulary consisting of the five
           letters after the selected letter (the displayed value will be capitalized, the stored value lowercase)."""
        numeric = ord(master)
        results = range(numeric+1,numeric+6)
        results = [(chr(a),chr(a).upper()) for a in results]
        return DisplayList(results)

registerType(MasterSelectDemo)
